@@ -1,20 +1,19 @@
 ## File Name: greenyang.reliability.R
-## File Version: 1.16
+## File Version: 1.22
 
 
-#--------------------------------------------------------------------------
-# Reliability from a multidimensional nonlinear SEM for dichotomous data
-greenyang.reliability <- function( object.tetra, nfactors){
-    TAM::require_namespace_msg("psych")
+#---- reliability from a multidimensional nonlinear SEM for dichotomous data
+greenyang.reliability <- function( object.tetra, nfactors)
+{
     cat("Reliability Estimation Based on a Nonlinear SEM\n\n")
     cat("Green & Yang (2009, Psychometrika). Reliability of summed item scores\n")
     cat("  using structural equation modeling: An alternative to coefficient alpha\n\n")
-    mod.omega1 <- psych::omega( m=object.tetra$rho, nfactors=1)
+    mod.omega1 <- sirt_import_psych_omega( m=object.tetra$rho, nfactors=1)
     # reliability for one factor
     rel1 <- reliability.nonlinearSEM( facloadings=matrix( mod.omega1$schmid$sl[,1], ncol=1 ),
                                 thresh=object.tetra$tau )$omega.rel
     # reliability for f factors
-    mod.omega <- psych::omega( m=object.tetra$rho, nfactors=nfactors)
+    mod.omega <- sirt_import_psych_omega( m=object.tetra$rho, nfactors=nfactors)
     rel1h <- reliability.nonlinearSEM( facloadings=matrix( mod.omega$schmid$sl[,1], ncol=1 ),
                                 thresh=object.tetra$tau )
     relf <- reliability.nonlinearSEM( facloadings=mod.omega$schmid$orthog,
@@ -35,14 +34,14 @@ greenyang.reliability <- function( object.tetra, nfactors){
                 rho.exp[ii1,ii2] <- rel1h$rho.exp[ii1,ii2]
                 rho.exp[ii2,ii1] <- rho.exp[ii1,ii2]
                 r1 <- rho.exp[ii1,ii2]
-                rel.matrix[ii1,ii2] <- mvtnorm::pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
+                rel.matrix[ii1,ii2] <- sirt_pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
                                          corr=matrix( c( 1, r1, r1, 1),2,2 ) ) - stats::pnorm( pthresh[ii1] ) * pnorm( pthresh[ii2] )
                 rel.matrix[ii2,ii1] <- rel.matrix[ii1,ii2]
                 # multidimensional analysis
                 rho.exp[ii1,ii2] <- relf$rho.exp[ii1,ii2]
                 rho.exp[ii2,ii1] <- rho.exp[ii1,ii2]
                 r1 <- rho.exp[ii1,ii2]
-                rel.matrix2[ii1,ii2] <- mvtnorm::pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
+                rel.matrix2[ii1,ii2] <- sirt_pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
                                          corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
                                          stats::pnorm( pthresh[ii1] ) * stats::pnorm( pthresh[ii2] )
                 rel.matrix2[ii2,ii1] <- rel.matrix2[ii1,ii2]
@@ -50,7 +49,7 @@ greenyang.reliability <- function( object.tetra, nfactors){
                 rel.matrix3[ii2,ii1] <- rel.matrix3[ii1,ii2]
                 if (ii1==ii2 ){
                     r1 <- 1
-                    rel.matrix3[ii1,ii2] <- mvtnorm::pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
+                    rel.matrix3[ii1,ii2] <- sirt_pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
                                              corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
                                                  stats::pnorm( pthresh[ii1] ) * stats::pnorm( pthresh[ii2] )
                     rel.matrix3[ii2,ii1] <- rel.matrix3[ii1,ii2]
@@ -99,9 +98,9 @@ greenyang.reliability <- function( object.tetra, nfactors){
     cat("\n\n")
     cat( paste( rep( ".", 45), collapse="") )
     cat( paste( "\n", 1, "-dimensional model\n\n",sep="") )
-    mod.omega1 <- psych::omega( m=object.tetra$rho, nfactors=1)
+    mod.omega1 <- sirt_import_psych_omega( m=object.tetra$rho, nfactors=1)
     print(mod.omega1)
     invisible(dfr1)
-    }
-#---------------------------------------------------------------------------
+}
+
 
