@@ -1,5 +1,5 @@
 ## File Name: invariance_alignment_summary_optimization.R
-## File Version: 0.05
+## File Version: 0.07
 
 invariance_alignment_summary_optimization <- function(object, digits)
 {
@@ -7,7 +7,8 @@ invariance_alignment_summary_optimization <- function(object, digits)
     align.scale <- object$align.scale
     cat("Optimization Function Value", "=", round(object$fopt[1],digits), "\n" )
     cat("Optimizer", "=", object$res_optim$optimizer, "\n" )
-    cat("Number of iterations", "=", object$res_optim$iter, "\n" )
+    cat("Fixed", "=", object$fixed, "\n" )
+    # cat("Number of iterations", "=", object$res_optim$iter, "\n" )
     cat("Converged", "=", object$res_optim$converged, "\n" )
     cat("Alignment Power Values","=", round(align.pow[1], digits),
                             round(align.pow[2], digits), "\n")
